@@ -238,7 +238,11 @@ class Horde_Service_Weather_Wwo extends Horde_Service_Weather_Base
 
         // Hack some data to allow UTC observation time to be returned.
         $results->data->current_condition[0]->date = new Horde_Date($results->data->current_condition[0]->localObsDateTime);
-        $results->data->current_condition[0]->date->hour += -$station->getOffset();
+        if (preg_match('/^(\+|-)?(\d{2}):(\d{2})/', $station->getOffset(), $match)) {
+            $factor = $match[1] == '-' ? -1 : 1;
+            $results->data->current_condition[0]->date->hour += $factor * $match[2];
+            $results->data->current_condition[0]->date->min  += $factor * $match[3];
+        }
 
         // Parse it.
         $this->_current = $this->_parseCurrent($results->data->current_condition);
@@ -289,7 +293,7 @@ class Horde_Service_Weather_Wwo extends Horde_Service_Weather_Base
         if (isset($station->timezone)) {
             // Only the *current* UTC offset is provided, with no indication
             // if we are in DST or not.
-            $properties['tz'] = $station->timezone[0]->offset;
+            $properties['tz'] = $station->timezone->offset;
         }
 
         return new Horde_Service_Weather_Station($properties);
